@@ -18,7 +18,7 @@
 
 // for getting the native mozilla drawing handle
 
-#ifdef MOZ_WIDGET_GTK2
+#ifdef NS_UNIX
 #include "gtkWidget.h"
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
@@ -64,7 +64,7 @@ BrowserWindow::Create ( Handle * hwnd, PRInt32 width, PRInt32 height)
 	if ( ! webBrowser )
 		return NS_ERROR_FAILURE;
 
-    (void)webBrowser->SetContainerWindow( NS_STATIC_CAST( nsIWebBrowserChrome*, this ) );
+    (void) webBrowser->SetContainerWindow (static_cast<nsIWebBrowserChrome *> (this));
 
     nsCOMPtr<nsIDocShellTreeItem> dsti = do_QueryInterface( webBrowser );
     dsti->SetItemType( nsIDocShellTreeItem::typeContentWrapper );
@@ -73,7 +73,7 @@ BrowserWindow::Create ( Handle * hwnd, PRInt32 width, PRInt32 height)
 	sessionHistory = do_CreateInstance(NS_SHISTORY_CONTRACTID);
 	webNav->SetSessionHistory(sessionHistory);
 
-    nsCOMPtr<nsIWindowCreator> windowCreator (NS_STATIC_CAST(nsIWindowCreator *, this));
+    nsCOMPtr<nsIWindowCreator> windowCreator (static_cast<nsIWindowCreator *> (this));
 
     // Attach it via the watcher service
     nsCOMPtr<nsIWindowWatcher> watcher = do_GetService(NS_WINDOWWATCHER_CONTRACTID);
@@ -104,14 +104,24 @@ BrowserWindow::Create ( Handle * hwnd, PRInt32 width, PRInt32 height)
 	RegisterComponents ();
 
 	
-    baseWindow = do_QueryInterface( webBrowser );
+    baseWindow = do_QueryInterface (webBrowser);
 	
 	result = baseWindow->InitWindow( hwnd, nsnull,  0, 0, width, height );
+	if (!NS_SUCCEEDED(result)) {
+		SHOUT("BrowserWindow: Failed to initialize window\n");
+		return NS_ERROR_FAILURE;
+	}
     result = baseWindow->Create();
+	if (!NS_SUCCEEDED(result)) {
+		SHOUT("BrowserWindow: Failed to create window\n");
+		return NS_ERROR_FAILURE;
+	}
 
-    nsCOMPtr< nsIWebProgressListener > listener( NS_STATIC_CAST( nsIWebProgressListener*, this ) );
-    nsCOMPtr< nsIWeakReference > thisListener( NS_GetWeakReference( listener ) );
-    (void)webBrowser->AddWebBrowserListener( thisListener, NS_GET_IID( nsIWebProgressListener ) );
+    nsCOMPtr<nsIWebProgressListener> wpl (static_cast<nsIWebProgressListener*>(this));
+    nsCOMPtr<nsIWeakReference> weakWpl (NS_GetWeakReference (wpl));
+    webBrowser->AddWebBrowserListener (weakWpl, NS_GET_IID (nsIWebProgressListener));
+
+//	webBrowser->SetParentURIContentListener (static_cast<nsIURIContentListener*>(this));
 
 	baseWindow->SetVisibility( PR_TRUE );
 
@@ -130,7 +140,7 @@ BrowserWindow::Create ( Handle * hwnd, PRInt32 width, PRInt32 height)
 		nsCOMPtr<nsIWidget> mozWidget;
 		baseWindow->GetMainWidget(getter_AddRefs(mozWidget));
 
-		GdkWindow *tmp_window = NS_STATIC_CAST(GdkWindow *, mozWidget->GetNativeData(NS_NATIVE_WINDOW));
+		GdkWindow *tmp_window = static_cast<GdkWindow *> (mozWidget->GetNativeData(NS_NATIVE_WINDOW));
 
 		// and, thanks to superwin we actually need the parent of that.
 		tmp_window = gdk_window_get_parent(tmp_window);
@@ -138,7 +148,7 @@ BrowserWindow::Create ( Handle * hwnd, PRInt32 width, PRInt32 height)
 		// save the widget ID - it should be the mozarea of the window.
 		gpointer data = nsnull;
 		gdk_window_get_user_data(tmp_window, &data);
-		this->nativeMozWidget = NS_STATIC_CAST(Handle *, data);
+		this->nativeMozWidget = static_cast<Handle *> (data);
 #endif		
 */
 		return NS_OK;
@@ -341,12 +351,13 @@ NS_INTERFACE_MAP_BEGIN(BrowserWindow)
 	NS_INTERFACE_MAP_ENTRY(nsIWebBrowserChromeFocus)
 	NS_INTERFACE_MAP_ENTRY(nsIInterfaceRequestor)
 	NS_INTERFACE_MAP_ENTRY(nsIWebProgressListener)
-	NS_INTERFACE_MAP_ENTRY(nsIURIContentListener)
+//	NS_INTERFACE_MAP_ENTRY(nsIURIContentListener)
 	NS_INTERFACE_MAP_ENTRY(nsSupportsWeakReference)
 	NS_INTERFACE_MAP_ENTRY_AMBIGUOUS(nsISupports, nsIWebProgressListener)
 	NS_INTERFACE_MAP_ENTRY(nsIWindowCreator)
 	NS_INTERFACE_MAP_ENTRY(nsIEmbeddingSiteWindow)
 	NS_INTERFACE_MAP_ENTRY(nsIEmbeddingSiteWindow2)
+	NS_INTERFACE_MAP_ENTRY(nsIContextMenuListener)
 NS_INTERFACE_MAP_END
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -373,7 +384,7 @@ NS_IMETHODIMP
 BrowserWindow::SetStatus(PRUint32 statusType, const PRUnichar *status)
 {
 	//statusText = (char *)NS_ConvertUTF16toUTF8( status ).get();
-	owner->events->OnStatusChange ("", 100);
+//	owner->events->OnStatusChange (status, 100);
 	return NS_OK;
 }
 
@@ -401,13 +412,13 @@ BrowserWindow::CreateChromeWindow(
 			nsIWebBrowserChrome **_retval)
 {
 
-	if (!this->owner->EventCreateNewWindow ())
-		return NS_ERROR_FAILURE;
+//	if (!owner->events->EventCreateNewWindow ())
+//		return NS_ERROR_FAILURE;
 
 	//if (aChromeFlags & nsIWebBrowserChrome::CHROME_OPENAS_CHROME)
 	//	this->isChrome = PR_TRUE;
 
-	*_retval = NS_STATIC_CAST(nsIWebBrowserChrome *, this);
+	*_retval = static_cast<nsIWebBrowserChrome *> (this);
 	
 	if (*_retval) {
 		NS_ADDREF(*_retval);
@@ -434,13 +445,13 @@ BrowserWindow::CreateChromeWindow(
 	// realized before that can happen.
 	gtk_widget_realize(GTK_WIDGET(newEmbed));
 	
-	Widget *newOwner = NS_STATIC_CAST(Widget *, newEmbed->data);
+	Widget *newOwner = static_cast<Widget *> (newEmbed->data);
 	
 	// set the chrome flag on the new window if it's a chrome open
 //	if (aChromeFlags & nsIWebBrowserChrome::CHROME_OPENAS_CHROME)
 //		newOwner->mIsChrome = PR_TRUE;
 	
-	*_retval = NS_STATIC_CAST(nsIWebBrowserChrome *, this);
+	*_retval = static_cast<nsIWebBrowserChrome *> (this);
 	
 	if (*_retval) {
 		NS_ADDREF(*_retval);
@@ -458,7 +469,7 @@ NS_IMETHODIMP
 BrowserWindow::OnStateChange(nsIWebProgress* progress, nsIRequest* request,
 										   PRUint32 state, nsresult status)
 {	
-	owner->EventStateChange(status, state);
+	owner->events->OnStateChange(progress, request, status, state);
 	
 	bool netstop = ( state & STATE_STOP ) && ( state & STATE_IS_NETWORK ) && ( status == NS_OK );
 	bool windowstop = ( state & STATE_STOP ) && ( state & STATE_IS_WINDOW ) && ( status == NS_OK );
@@ -476,7 +487,7 @@ BrowserWindow::OnStateChange(nsIWebProgress* progress, nsIRequest* request,
 		nsCOMPtr< nsIDOMEventTarget > target = do_QueryInterface( window );
 		AttachEvent ( target, "window", "load" );
 		AttachEvent ( target, "window", "unload" );
-#ifndef XP_WIN32
+#ifndef NS_WIN32
 		AttachEvent ( target, "window", "focus" );
 #endif
 		AttachEvent ( target, "window", "blur" );
@@ -492,10 +503,10 @@ BrowserWindow::OnStateChange(nsIWebProgress* progress, nsIRequest* request,
 		AttachEvent ( target, "window", "change" );
 		AttachEvent ( target, "window", "submit" );
 		AttachEvent ( target, "window", "reset" );
-		AttachEvent ( target, "window", "keyup" );
 		
 		AttachEvent ( target, "window", "keydown" );
 		AttachEvent ( target, "window", "keypress" );
+		AttachEvent ( target, "window", "keyup" );
 
 		AttachEvent ( target, "window", "click" );
 		AttachEvent ( target, "window", "dblclick" );
@@ -503,6 +514,7 @@ BrowserWindow::OnStateChange(nsIWebProgress* progress, nsIRequest* request,
 		AttachEvent ( target, "window", "mouseup" );
 		AttachEvent ( target, "window", "mouseover" );
 		AttachEvent ( target, "window", "mouseout" );
+		AttachEvent ( target, "window", "mousemove" );
 		
 		AttachEvent ( target, "window", "popupshowing" );
 		AttachEvent ( target, "window", "popupshown" );
@@ -564,88 +576,91 @@ BrowserWindow::ExitModalEventLoop(nsresult aStatus)
 
 /* void onProgressChange (in nsIWebProgress aWebProgress, in nsIRequest aRequest, in long aCurSelfProgress, in long aMaxSelfProgress, in long aCurTotalProgress, in long aMaxTotalProgress); */
 NS_IMETHODIMP 
-BrowserWindow::OnProgressChange(nsIWebProgress *aWebProgress, nsIRequest *aRequest, PRInt32 aCurSelfProgress, PRInt32 aMaxSelfProgress, PRInt32 aCurTotalProgress, PRInt32 aMaxTotalProgress)
-{
-    return NS_ERROR_NOT_IMPLEMENTED;
+BrowserWindow::OnProgressChange(nsIWebProgress *webProgress, nsIRequest *request, PRInt32 aCurSelfProgress, PRInt32 aMaxSelfProgress, PRInt32 aCurTotalProgress, PRInt32 aMaxTotalProgress)
+{	
+	owner->events->OnProgress(webProgress, request, aCurTotalProgress, aMaxTotalProgress);
+    return NS_OK;
 }
 
 /* void onLocationChange (in nsIWebProgress aWebProgress, in nsIRequest aRequest, in nsIURI aLocation); */
 NS_IMETHODIMP 
-BrowserWindow::OnLocationChange(nsIWebProgress *aWebProgress, nsIRequest *aRequest, nsIURI *location)
+BrowserWindow::OnLocationChange(nsIWebProgress *webProgress, nsIRequest *request, nsIURI *location)
 {
-	nsCString url;
-	location->GetSpec (url);
-    owner->EventLocationChanged(url.BeginReading ());
+    owner->events->OnLocationChanged(webProgress, request, location);
 	return NS_OK;
 }
 
 /* void onStatusChange (in nsIWebProgress aWebProgress, in nsIRequest aRequest, in nsresult aStatus, in wstring aMessage); */
 NS_IMETHODIMP 
-BrowserWindow::OnStatusChange(nsIWebProgress *aWebProgress, nsIRequest *aRequest, nsresult aStatus, const PRUnichar *aMessage)
+BrowserWindow::OnStatusChange(nsIWebProgress *webProgress, nsIRequest *request, nsresult aStatus, const PRUnichar *aMessage)
 {
-	statusText = (char *)NS_ConvertUTF16toUTF8( aMessage ).get();
-	owner->events->OnStatusChange (statusText, aStatus);
+	PRINT ("gluezilla: OnStatusChange\n");
+	owner->events->OnStatusChange (webProgress, request, aMessage, aStatus);
     return NS_OK;
 }
 
 /* void onSecurityChange (in nsIWebProgress aWebProgress, in nsIRequest aRequest, in unsigned long aState); */
 NS_IMETHODIMP 
-BrowserWindow::OnSecurityChange(nsIWebProgress *aWebProgress, nsIRequest *aRequest, PRUint32 aState)
+BrowserWindow::OnSecurityChange (nsIWebProgress *webProgress, nsIRequest *request, PRUint32 state)
 {
-    return NS_ERROR_NOT_IMPLEMENTED;
+    owner->events->OnSecurityChange (webProgress, request, state);
+	return NS_OK;
 }
 
+
+/* nsIURIContentListener */
+
 /* boolean onStartURIOpen (in nsIURI aURI); */
-NS_IMETHODIMP 
-BrowserWindow::OnStartURIOpen(nsIURI *aURI, PRBool *_retval)
-{
-    return NS_ERROR_NOT_IMPLEMENTED;
-}
+//NS_IMETHODIMP 
+//BrowserWindow::OnStartURIOpen(nsIURI *aURI, PRBool *_retval)
+//{
+//    return NS_ERROR_NOT_IMPLEMENTED;
+//}
 
 /* boolean doContent (in string aContentType, in boolean aIsContentPreferred, in nsIRequest aRequest, out nsIStreamListener aContentHandler); */
-NS_IMETHODIMP 
-BrowserWindow::DoContent(const char *aContentType, PRBool aIsContentPreferred, nsIRequest *aRequest, nsIStreamListener **aContentHandler, PRBool *_retval)
-{
-    return NS_ERROR_NOT_IMPLEMENTED;
-}
+//NS_IMETHODIMP 
+//BrowserWindow::DoContent(const char *aContentType, PRBool aIsContentPreferred, nsIRequest *aRequest, nsIStreamListener **aContentHandler, PRBool *_retval)
+//{
+//    return NS_ERROR_NOT_IMPLEMENTED;
+//}
 
 /* boolean isPreferred (in string aContentType, out string aDesiredContentType); */
-NS_IMETHODIMP 
-BrowserWindow::IsPreferred(const char *aContentType, char **aDesiredContentType, PRBool *_retval)
-{
-    return NS_ERROR_NOT_IMPLEMENTED;
-}
+//NS_IMETHODIMP 
+//BrowserWindow::IsPreferred(const char *aContentType, char **aDesiredContentType, PRBool *_retval)
+//{
+//    return NS_ERROR_NOT_IMPLEMENTED;
+//}
 
 /* boolean canHandleContent (in string aContentType, in boolean aIsContentPreferred, out string aDesiredContentType); */
-NS_IMETHODIMP 
-BrowserWindow::CanHandleContent(const char *aContentType, PRBool aIsContentPreferred, char **aDesiredContentType, PRBool *_retval)
-{
-    return NS_ERROR_NOT_IMPLEMENTED;
-}
+//NS_IMETHODIMP 
+//BrowserWindow::CanHandleContent(const char *aContentType, PRBool aIsContentPreferred, char **aDesiredContentType, PRBool *_retval)
+//{
+//    return NS_ERROR_NOT_IMPLEMENTED;
+//}
 
 /* attribute nsISupports loadCookie; */
-NS_IMETHODIMP 
-BrowserWindow::GetLoadCookie(nsISupports * *aLoadCookie)
-{
-    return NS_ERROR_NOT_IMPLEMENTED;
-}
-NS_IMETHODIMP 
-BrowserWindow::SetLoadCookie(nsISupports * aLoadCookie)
-{
-    return NS_ERROR_NOT_IMPLEMENTED;
-}
+//NS_IMETHODIMP 
+//BrowserWindow::GetLoadCookie(nsISupports * *aLoadCookie)
+//{
+//    return NS_ERROR_NOT_IMPLEMENTED;
+//}
+//NS_IMETHODIMP 
+//BrowserWindow::SetLoadCookie(nsISupports * aLoadCookie)
+//{
+//    return NS_ERROR_NOT_IMPLEMENTED;
+//}
 
 /* attribute nsIURIContentListener parentContentListener; */
-NS_IMETHODIMP 
-BrowserWindow::GetParentContentListener(nsIURIContentListener * *aParentContentListener)
-{
-    return NS_ERROR_NOT_IMPLEMENTED;
-}
-NS_IMETHODIMP 
-BrowserWindow::SetParentContentListener(nsIURIContentListener * aParentContentListener)
-{
-    return NS_ERROR_NOT_IMPLEMENTED;
-}
+//NS_IMETHODIMP 
+//BrowserWindow::GetParentContentListener(nsIURIContentListener * *aParentContentListener)
+//{
+//    return NS_ERROR_NOT_IMPLEMENTED;
+//}
+//NS_IMETHODIMP 
+//BrowserWindow::SetParentContentListener(nsIURIContentListener * aParentContentListener)
+//{
+//    return NS_ERROR_NOT_IMPLEMENTED;
+//}
 
 
 
@@ -722,7 +737,7 @@ BrowserWindow::SetTitle(const PRUnichar * aTitle)
 NS_IMETHODIMP 
 BrowserWindow::GetSiteWindow(void * *aSiteWindow)
 {
-  *aSiteWindow = NS_STATIC_CAST(void *, owner->getHandle());
+  *aSiteWindow = static_cast<void *> (owner->getHandle());
   return NS_OK;
 }
 
@@ -741,3 +756,15 @@ BrowserWindow::FocusPrevElement()
 {
     return NS_ERROR_NOT_IMPLEMENTED;
 }
+
+// nsIContextMenuListener
+
+NS_IMETHODIMP 
+BrowserWindow::OnShowContextMenu (PRUint32 contextFlags, nsIDOMEvent * event, nsIDOMNode * node)
+{
+	PRINT ("gluezilla: OnShowContextMenu\n");
+	owner->events->OnShowContextMenu (contextFlags, event, node);
+	return NS_OK;
+}
+
+
